@@ -1,7 +1,7 @@
 package LWP::UserAgent::ProxyAny;
 use strict;
 use warnings;
-our $VERSION = "1.01";
+our $VERSION = "1.02";
 use base qw(LWP::UserAgent);
 
 sub env_proxy {
@@ -130,10 +130,32 @@ Set proxy settings from $name.
 
 Return current IE proxy settings and set $ie_proxy_no as proxy override settings.
 
+=head1 NOTES ABOUT IIS
+
+When running under Microsoft IIS, ProxyAny will try to read IE proxy settings
+from current user's registry. Under default setting of IIS, the current user to
+anonymous browsering is IUSR_(hostname) or IWAM_(hostname), and ProxyAny will
+read registry from .DEFAULT users instead of from login user.
+
+So if you want to use ProxyAny under IIS, you'd better change your IIS anonymous
+browsering settings from IUSR_(hostname) to your login user name.
+
+1. Open your IIS management interface.
+
+2. Select your web site, and right click to define properties.
+
+3. Go to "Directory Security" Tab, and click "edit" under Anonymous
+and Authentication groups.
+
+4. Enable Anonymous and edit your anonymous accounts, change it from
+IUSR_(hostname) or IWAM_(hostname) to your user name.
+
+Thanks Rich Mellor<RWAPSoftware@aol.com> for this notes.
+
 =head1 BUGS, REQUESTS, COMMENTS
 
 Please report any requests, suggestions or bugs via
-http://sourceforge.net/projects/bookbot
+http://bookbot.sourceforge.net/
 http://rt.cpan.org/NoAuth/ReportBug.html?Queue=LWP-UserAgent-ProxyAny
 
 =head1 SEE ALSO
